@@ -49,6 +49,7 @@
 
 package com.openexchange.admin.reseller.storage.mysqlStorage;
 
+import static com.openexchange.database.Databases.closeSQLStuff;
 import static com.openexchange.tools.sql.DBUtils.getIN;
 import java.io.UnsupportedEncodingException;
 import java.security.NoSuchAlgorithmException;
@@ -61,13 +62,10 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
-import java.util.LinkedList;
-import java.util.List;
 import java.util.Map;
 import com.openexchange.admin.exceptions.OXGenericException;
 import com.openexchange.admin.reseller.daemons.ClientAdminThreadExtended;
 import com.openexchange.admin.reseller.rmi.OXResellerTools;
-import com.openexchange.admin.reseller.rmi.dataobjects.CustomField;
 import com.openexchange.admin.reseller.rmi.dataobjects.ResellerAdmin;
 import com.openexchange.admin.reseller.rmi.dataobjects.Restriction;
 import com.openexchange.admin.reseller.rmi.exceptions.OXResellerException;
@@ -82,12 +80,10 @@ import com.openexchange.admin.rmi.exceptions.InvalidDataException;
 import com.openexchange.admin.rmi.exceptions.PoolException;
 import com.openexchange.admin.rmi.exceptions.StorageException;
 import com.openexchange.admin.tools.AdminCache;
-import com.openexchange.database.Databases;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.impl.IDGenerator;
 import com.openexchange.groupware.userconfiguration.RdbUserPermissionBitsStorage;
 import com.openexchange.groupware.userconfiguration.UserPermissionBits;
-import com.openexchange.tools.sql.DBUtils;
 
 /**
  * @author choeger
@@ -110,8 +106,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
         cache = ClientAdminThreadExtended.cache;
     }
 
-    public OXResellerMySQLStorage() {
-    }
+    public OXResellerMySQLStorage() {}
 
     @Override
     public void change(final ResellerAdmin adm) throws StorageException {
@@ -355,7 +350,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
         PreparedStatement prep = null;
         ResultSet rs = null;
         String query = "SELECT * FROM subadmin WHERE ( sid LIKE ? OR name LIKE ?)";
-        if( pid > 0 ) {
+        if (pid > 0) {
             query += " AND pid=?";
         }
         try {
@@ -364,7 +359,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             prep = con.prepareStatement(query);
             prep.setString(1, search_patterntmp);
             prep.setString(2, search_patterntmp);
-            if( pid > 0 ) {
+            if (pid > 0) {
                 prep.setInt(3, pid);
             }
             rs = prep.executeQuery();
@@ -428,7 +423,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             prep.close();
             return admin;
         } finally {
-            DBUtils.closeSQLStuff(rs, prep);
+            closeSQLStuff(rs, prep);
         }
     }
 
@@ -459,7 +454,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
                 } else {
                     throw new InvalidDataException("either ID or name must be specified");
                 }
-                if( pid > 0 ) {
+                if (pid > 0) {
                     query += " AND pid=?";
                 }
                 prep = con.prepareStatement(query);
@@ -468,13 +463,12 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
                 } else {
                     prep.setString(1, adm.getName());
                 }
-                if(pid > 0) {
+                if (pid > 0) {
                     prep.setInt(2, pid);
                 }
                 rs = prep.executeQuery();
                 if (!rs.next()) {
-                    throw new StorageException(
-                        "unable to get data of reseller admin: " + (hasId ? "id=" + adm.getId() : "name=" + adm.getName()));
+                    throw new StorageException("unable to get data of reseller admin: " + (hasId ? "id=" + adm.getId() : "name=" + adm.getName()));
                 }
                 newadm.setName(rs.getString(DATABASE_COLUMN_NAME));
                 newadm.setId(rs.getInt("sid"));
@@ -546,7 +540,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
                 } else {
                     throw new InvalidDataException("either ID or name must be specified");
                 }
-                if( pid > 0 ) {
+                if (pid > 0) {
                     query += " AND pid=?";
                 }
                 prep = con.prepareStatement(query);
@@ -555,7 +549,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
                 } else {
                     prep.setString(1, name);
                 }
-                if(pid > 0) {
+                if (pid > 0) {
                     prep.setInt(2, pid);
                 }
                 rs = prep.executeQuery();
@@ -581,73 +575,6 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
         }
     }
 
-    @Override
-    public void restore(Context ctx, int subadmin, Restriction[] restrictions, CustomField[] customFields) throws StorageException {
-        Connection oxcon = null;
-        PreparedStatement prep = null;
-
-        log.debug("restore {}", ctx.getId());
-
-        boolean rollback = false;
-        try {
-            oxcon = cache.getWriteConnectionForConfigDB();
-            oxcon.setAutoCommit(false);
-            rollback = true;
-
-            if (subadmin > 0) {
-                prep = oxcon.prepareStatement("INSERT INTO context2subadmin (sid,cid) VALUES(?,?)");
-                prep.setInt(1, subadmin);
-                prep.setInt(2, ctx.getId().intValue());
-                prep.executeUpdate();
-                Databases.closeSQLStuff(prep);
-                prep = null;
-            }
-
-            if (restrictions != null) {
-                for (Restriction r : restrictions) {
-                    prep = oxcon.prepareStatement("INSERT INTO context_restrictions (cid,rid,value) VALUES (?,?,?)");
-                    prep.setInt(1, ctx.getId().intValue());
-                    prep.setInt(2, r.getId().intValue());
-                    prep.setString(3, r.getValue());
-                    prep.executeUpdate();
-                    Databases.closeSQLStuff(prep);
-                    prep = null;
-                }
-            }
-
-            if (customFields != null) {
-                for (CustomField customField : customFields) {
-                    prep = oxcon.prepareStatement("INSERT INTO context_customfields (cid, customid, createTimestamp, modifyTimestamp) VALUES (?,?, ?, ?)");
-                    prep.setInt(1, ctx.getId().intValue());
-                    prep.setString(2, customField.getCustomId());
-                    prep.setLong(3, customField.getCreateTimestamp());
-                    prep.setLong(4, customField.getModifyTimestamp());
-                    prep.executeUpdate();
-                    Databases.closeSQLStuff(prep);
-                    prep = null;
-                }
-            }
-        } catch (final DataTruncation dt) {
-            log.error(AdminCache.DATA_TRUNCATION_ERROR_MSG, dt);
-            throw AdminCache.parseDataTruncation(dt);
-        } catch (final RuntimeException e) {
-            log.error("", e);
-            throw e;
-        } catch (final PoolException e) {
-            log.error("", e);
-            // no Rollback needed as the connection is null at this moment
-            throw new StorageException(e.getMessage());
-        } catch (final SQLException e) {
-            log.error("", e);
-            throw new StorageException(e.getMessage());
-        } finally {
-            if (rollback) {
-                doRollback(oxcon);
-            }
-            cache.closeWriteConfigDBSqlStuff(oxcon, prep);
-        }
-    }
-
     @Override
     public void ownContextToAdmin(final Context ctx, final Credentials creds) throws StorageException {
         Connection oxcon = null;
@@ -696,10 +623,10 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
     }
 
     @Override
-    public int unownContextFromAdmin(final Context ctx, final Credentials creds) throws StorageException {
+    public void unownContextFromAdmin(final Context ctx, final Credentials creds) throws StorageException {
         try {
             final ResellerAdmin adm = getData(new ResellerAdmin[] { new ResellerAdmin(creds.getLogin(), creds.getPassword()) })[0];
-            return unownContextFromAdmin(ctx, adm);
+            unownContextFromAdmin(ctx, adm);
         } catch (final RuntimeException e) {
             log.error("", e);
             throw e;
@@ -707,7 +634,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
     }
 
     @Override
-    public int unownContextFromAdmin(final Context ctx, final ResellerAdmin adm) throws StorageException {
+    public void unownContextFromAdmin(final Context ctx, final ResellerAdmin adm) throws StorageException {
         Connection oxcon = null;
         PreparedStatement prep = null;
 
@@ -725,17 +652,13 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             oxcon.setAutoCommit(false);
             rollback = true;
 
-            int subadminId = adm.getId().intValue();
-
             prep = oxcon.prepareStatement("DELETE FROM context2subadmin WHERE sid=? AND cid=?");
-            prep.setInt(1, subadminId);
-            prep.setInt(2, ctx.getId().intValue());
+            prep.setInt(1, adm.getId());
+            prep.setInt(2, ctx.getId());
             prep.executeUpdate();
 
             oxcon.commit();
             rollback = false;
-
-            return subadminId;
         } catch (final DataTruncation dt) {
             log.error(AdminCache.DATA_TRUNCATION_ERROR_MSG, dt);
             throw AdminCache.parseDataTruncation(dt);
@@ -1006,7 +929,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             final int pid = adm.getParentId();
             prep = con.prepareStatement(getIN(query, pid > 0 ? 2 : 1));
             prep.setInt(1, adm.getId());
-            if( pid > 0 ) {
+            if (pid > 0) {
                 prep.setInt(2, pid);
             }
             rs = prep.executeQuery();
@@ -1131,7 +1054,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             prep = con.prepareStatement("SELECT COUNT(sid) FROM subadmin WHERE pid=?");
             prep.setInt(1, adm.getId());
             rs = prep.executeQuery();
-            if( rs.next() ) {
+            if (rs.next()) {
                 final int count = rs.getInt(1);
                 if (count >= maxvalue) {
                     throw new OXResellerException(Code.MAXIMUM_NUMBER_OF_SUBADMIN_PER_SUBADMIN_REACHED, String.valueOf(maxvalue));
@@ -1145,7 +1068,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
         }
     }
 
-    private boolean isSameModuleAccess(final UserModuleAccess a, final UserModuleAccess b ) {
+    private boolean isSameModuleAccess(final UserModuleAccess a, final UserModuleAccess b) {
         return a.equals(b);
     }
 
@@ -1177,7 +1100,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             ubp.setOLOX20(access.isOLOX20());
 
             final int ret = RdbUserPermissionBitsStorage.adminCountUsersByPermission(ctx.getId().intValue(), ubp, null);
-            if( ret < 0 ) {
+            if (ret < 0) {
                 throw new StorageException("unable to count number of users by module access");
             }
             return ret;
@@ -1195,15 +1118,13 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
         ResultSet rs = null;
         int cid = -1;
         try {
-            if( newaccess == null ) {
+            if (newaccess == null) {
                 throw new OXResellerException(Code.MODULE_ACCESS_NOT_NULL);
             }
             cache.initAccessCombinations();
             final String name = res.getName();
-            final UserModuleAccess namedaccess =
-                cache.getNamedAccessCombination(
-                    name.substring(Restriction.MAX_OVERALL_USER_PER_SUBADMIN_BY_MODULEACCESS_PREFIX.length()), contextAdmin);
-            if(isSameModuleAccess(newaccess, namedaccess)) {
+            final UserModuleAccess namedaccess = cache.getNamedAccessCombination(name.substring(Restriction.MAX_OVERALL_USER_PER_SUBADMIN_BY_MODULEACCESS_PREFIX.length()), contextAdmin);
+            if (isSameModuleAccess(newaccess, namedaccess)) {
 
                 prep = con.prepareStatement("SELECT cid FROM context2subadmin WHERE sid=?");
                 prep.setInt(1, admid);
@@ -1217,8 +1138,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
                     final Context ctx = new Context(cid);
                     count += countUsersByModuleAccess(ctx, namedaccess);
                     if (count > maxvalue) {
-                        throw new OXResellerException(Code.MAXIMUM_OVERALL_NUMBER_OF_USERS_BY_MODULEACCESS_REACHED,
-                            name + ":" + String.valueOf(maxvalue));
+                        throw new OXResellerException(Code.MAXIMUM_OVERALL_NUMBER_OF_USERS_BY_MODULEACCESS_REACHED, name + ":" + String.valueOf(maxvalue));
                     }
                 }
             }
@@ -1290,14 +1210,11 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
         try {
             cache.initAccessCombinations();
             final String name = res.getName();
-            final UserModuleAccess namedaccess =
-                cache.getNamedAccessCombination(
-                    name.substring(Restriction.MAX_USER_PER_CONTEXT_BY_MODULEACCESS_PREFIX.length()), contextAdmin);
-            if(isSameModuleAccess(newaccess, namedaccess)) {
+            final UserModuleAccess namedaccess = cache.getNamedAccessCombination(name.substring(Restriction.MAX_USER_PER_CONTEXT_BY_MODULEACCESS_PREFIX.length()), contextAdmin);
+            if (isSameModuleAccess(newaccess, namedaccess)) {
                 final int maxvalue = Integer.parseInt(res.getValue());
-                if(countUsersByModuleAccess(ctx, namedaccess) > maxvalue) {
-                    throw new OXResellerException(Code.MAXIMUM_OVERALL_NUMBER_OF_USERS_BY_MODULEACCESS_REACHED,
-                        name + ":" + String.valueOf(maxvalue));
+                if (countUsersByModuleAccess(ctx, namedaccess) > maxvalue) {
+                    throw new OXResellerException(Code.MAXIMUM_OVERALL_NUMBER_OF_USERS_BY_MODULEACCESS_REACHED, name + ":" + String.valueOf(maxvalue));
                 }
 
             }
@@ -1312,6 +1229,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
 
     /*
      * (non-Javadoc)
+     *
      * @see
      * com.openexchange.admin.reseller.storage.interfaces.OXResellerStorageInterface#checkRestrictions(com.openexchange.admin.rmi.dataobjects
      * .Credentials)
@@ -1322,12 +1240,12 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
         final ResellerAdmin adm = getData(new ResellerAdmin[] { new ResellerAdmin(creds.getLogin(), creds.getPassword()) })[0];
         HashSet<Restriction> restrictions = OXResellerTools.array2HashSet(adm.getRestrictions());
         // default is: not allowed to create SUBADMINS
-        if( restrictions == null ) {
+        if (restrictions == null) {
             restrictions = new HashSet<Restriction>();
         }
         {
             Restriction subadminCanCreateSubadminsRestriction = new Restriction(Restriction.SUBADMIN_CAN_CREATE_SUBADMINS, "false");
-            if( ! restrictions.contains(subadminCanCreateSubadminsRestriction) ) { // Contains is solely performed by name
+            if (!restrictions.contains(subadminCanCreateSubadminsRestriction)) { // Contains is solely performed by name
                 restrictions.add(subadminCanCreateSubadminsRestriction);
             }
         }
@@ -1356,7 +1274,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
                                 //long tend = System.currentTimeMillis();
                                 //System.out.println("checkMaxOverallUserRestriction: " + (tend - tstart) + " ms");
                             } else if (tocheck.equals(Restriction.SUBADMIN_CAN_CREATE_SUBADMINS)) {
-                                if( !OXResellerTools.isTrue(value) ) {
+                                if (!OXResellerTools.isTrue(value)) {
                                     throw new OXResellerException(OXResellerException.Code.SUBADMIN_NOT_ALLOWED_TO_CREATE_SUBADMIN, adm.getName());
                                 }
                             } else if (tocheck.equals(Restriction.MAX_SUBADMIN_PER_SUBADMIN)) {
@@ -1398,6 +1316,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
 
     /*
      * (non-Javadoc)
+     *
      * @see
      * com.openexchange.admin.reseller.storage.interfaces.OXResellerStorageInterface#checkPerContextRestrictions(com.openexchange.admin.
      * rmi.dataobjects.Context, java.lang.String[])
@@ -1416,14 +1335,12 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
                 for (final Restriction res : admrestrictions) {
                     final String name = res.getName();
                     for (final String tocheck : restriction_types) {
-                        if (tocheck.equals(Restriction.MAX_OVERALL_USER_PER_SUBADMIN) &&
-                            name.equals(Restriction.MAX_OVERALL_USER_PER_SUBADMIN)) {
+                        if (tocheck.equals(Restriction.MAX_OVERALL_USER_PER_SUBADMIN) && name.equals(Restriction.MAX_OVERALL_USER_PER_SUBADMIN)) {
                             //long tstart = System.currentTimeMillis();
                             checkMaxOverallUserRestriction(con, adm, Integer.parseInt(res.getValue()), false);
                             //long tend = System.currentTimeMillis();
                             //System.out.println("checkMaxOverallUserRestriction: " + (tend - tstart) + " ms");
-                        } else if (tocheck.equals(Restriction.MAX_OVERALL_USER_PER_SUBADMIN_BY_MODULEACCESS_PREFIX) &&
-                            name.startsWith(Restriction.MAX_OVERALL_USER_PER_SUBADMIN_BY_MODULEACCESS_PREFIX) ) {
+                        } else if (tocheck.equals(Restriction.MAX_OVERALL_USER_PER_SUBADMIN_BY_MODULEACCESS_PREFIX) && name.startsWith(Restriction.MAX_OVERALL_USER_PER_SUBADMIN_BY_MODULEACCESS_PREFIX)) {
                             //long tstart = System.currentTimeMillis();
                             checkMaxOverallUserRestrictionByModuleAccess(con, adm.getId(), res, access, false, contextAdmin);
                             //long tend = System.currentTimeMillis();
@@ -1436,14 +1353,12 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
                 for (final Restriction res : ctxrestrictions) {
                     final String name = res.getName();
                     for (final String tocheck : restriction_types) {
-                        if (tocheck.equals(Restriction.MAX_USER_PER_CONTEXT) &&
-                            name.equals(Restriction.MAX_USER_PER_CONTEXT) ) {
+                        if (tocheck.equals(Restriction.MAX_USER_PER_CONTEXT) && name.equals(Restriction.MAX_USER_PER_CONTEXT)) {
                             //long tstart = System.currentTimeMillis();
                             checkMaxUserRestriction(ctx, Integer.parseInt(res.getValue()));
                             //long tend = System.currentTimeMillis();
                             //System.out.println("checkMaxUserRestriction: " + (tend - tstart) + " ms");
-                        } else if (tocheck.equals(Restriction.MAX_USER_PER_CONTEXT_BY_MODULEACCESS_PREFIX) &&
-                            name.startsWith(Restriction.MAX_USER_PER_CONTEXT_BY_MODULEACCESS_PREFIX) ) {
+                        } else if (tocheck.equals(Restriction.MAX_USER_PER_CONTEXT_BY_MODULEACCESS_PREFIX) && name.startsWith(Restriction.MAX_USER_PER_CONTEXT_BY_MODULEACCESS_PREFIX)) {
                             //long tstart = System.currentTimeMillis();
                             checkMaxUserRestrictionByModuleAccess(ctx, res, access, contextAdmin);
                             //long tend = System.currentTimeMillis();
@@ -1508,17 +1423,15 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
 
     /*
      * (non-Javadoc)
+     *
      * @see com.openexchange.admin.reseller.storage.interfaces.OXResellerStorageInterface#applyRestrictionsToContext(java.util.HashSet,
      * com.openexchange.admin.rmi.dataobjects.Context)
      */
     @Override
-    public Restriction[] applyRestrictionsToContext(final Restriction[] restrictions, final Context ctx) throws StorageException {
+    public void applyRestrictionsToContext(final Restriction[] restrictions, final Context ctx) throws StorageException {
         log.debug("applyRestrictionsToContext {}", ctx);
         Connection oxcon = null;
         PreparedStatement prep = null;
-        ResultSet rs = null;
-
-        List<Restriction> dropped = null;
 
         boolean rollback = false;
         try {
@@ -1526,35 +1439,19 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             oxcon.setAutoCommit(false);
             rollback = true;
 
-            final int cid = ctx.getId().intValue();
-            prep = oxcon.prepareStatement("SELECT rid, value FROM context_restrictions WHERE cid=?");
-            prep.setInt(1, cid);
-            rs = prep.executeQuery();
-            if (rs.next()) {
-                dropped = new LinkedList<Restriction>();
-                do {
-                    dropped.add(new Restriction(Integer.valueOf(rs.getInt(1)), null, rs.getString(2)));
-                } while (rs.next());
-            }
-            Databases.closeSQLStuff(rs, prep);
-            rs = null;
-            prep = null;
-
+            final int cid = ctx.getId();
             prep = oxcon.prepareStatement("DELETE FROM context_restrictions WHERE cid=?");
             prep.setInt(1, cid);
             prep.executeUpdate();
-            Databases.closeSQLStuff(prep);
-            prep = null;
-
+            prep.close();
             if (restrictions != null) {
                 for (final Restriction r : restrictions) {
                     prep = oxcon.prepareStatement("INSERT INTO context_restrictions (cid,rid,value) VALUES (?,?,?)");
                     prep.setInt(1, cid);
-                    prep.setInt(2, r.getId().intValue());
+                    prep.setInt(2, r.getId());
                     prep.setString(3, r.getValue());
                     prep.executeUpdate();
-                    Databases.closeSQLStuff(prep);
-                    prep = null;
+                    prep.close();
                 }
             }
 
@@ -1576,14 +1473,13 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             if (rollback) {
                 doRollback(oxcon);
             }
-            cache.closeWriteConfigDBSqlStuff(oxcon, prep, rs);
+            cache.closeWriteConfigDBSqlStuff(oxcon, prep);
         }
-
-        return dropped == null ? new Restriction[0] : dropped.toArray(new Restriction[dropped.size()]);
     }
 
     /*
      * (non-Javadoc)
+     *
      * @see
      * com.openexchange.admin.reseller.storage.interfaces.OXResellerStorageInterface#getRestrictionsFromContext(com.openexchange.admin.rmi
      * .dataobjects.Context)
@@ -1619,10 +1515,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
 
             final HashSet<Restriction> res = new HashSet<Restriction>();
             while (rs.next()) {
-                res.add(new Restriction(
-                    rs.getInt(DATABASE_COLUMN_ID),
-                    rs.getString(DATABASE_COLUMN_NAME),
-                    rs.getString(DATABASE_COLUMN_VALUE)));
+                res.add(new Restriction(rs.getInt(DATABASE_COLUMN_ID), rs.getString(DATABASE_COLUMN_NAME), rs.getString(DATABASE_COLUMN_VALUE)));
             }
             return res.size() > 0 ? res.toArray(new Restriction[res.size()]) : null;
         } catch (final SQLException e) {
@@ -1635,6 +1528,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
 
     /*
      * (non-Javadoc)
+     *
      * @see com.openexchange.admin.reseller.storage.interfaces.OXResellerStorageInterface#initDatabaseRestrictions()
      */
     @Override
@@ -1659,9 +1553,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             }
             cache.initAccessCombinations();
             for (final String mname : cache.getAccessCombinationNames().keySet()) {
-                for (final String prefix : new String[] {
-                    Restriction.MAX_OVERALL_USER_PER_SUBADMIN_BY_MODULEACCESS_PREFIX,
-                    Restriction.MAX_USER_PER_CONTEXT_BY_MODULEACCESS_PREFIX}) {
+                for (final String prefix : new String[] { Restriction.MAX_OVERALL_USER_PER_SUBADMIN_BY_MODULEACCESS_PREFIX, Restriction.MAX_USER_PER_CONTEXT_BY_MODULEACCESS_PREFIX }) {
                     final int rid = IDGenerator.getId(con);
                     prep = con.prepareStatement("INSERT INTO restrictions (rid,name) VALUES (?,?)");
                     prep.setInt(1, rid);
@@ -1695,6 +1587,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
 
     /*
      * (non-Javadoc)
+     *
      * @see com.openexchange.admin.reseller.storage.interfaces.OXResellerStorageInterface#removeDatabaseRestrictions()
      */
     @Override
@@ -1727,7 +1620,9 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
         }
     }
 
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     *
      * @see com.openexchange.admin.reseller.storage.interfaces.OXResellerStorageInterface#getCustomId(com.openexchange.admin.rmi.dataobjects.Context)
      */
     @Override
@@ -1756,7 +1651,9 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
         }
     }
 
-    /* (non-Javadoc)
+    /*
+     * (non-Javadoc)
+     *
      * @see com.openexchange.admin.reseller.storage.interfaces.OXResellerStorageInterface#writeCustomId(com.openexchange.admin.rmi.dataobjects.Context)
      */
     @Override
@@ -1766,19 +1663,19 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
         PreparedStatement prep = null;
         ResultSet rs = null;
         final OXContextExtensionImpl contextExtension = (OXContextExtensionImpl) ctx.getFirstExtensionByName(OXContextExtensionImpl.class.getName());
-        if( contextExtension != null && contextExtension.getCustomid() != null ) {
+        if (contextExtension != null && contextExtension.getCustomid() != null) {
             try {
                 con = cache.getWriteConnectionForConfigDB();
                 prep = con.prepareStatement("SELECT cid FROM context_customfields WHERE cid=?");
                 prep.setInt(1, ctx.getId());
                 rs = prep.executeQuery();
                 boolean idexists = false;
-                if( rs.next() ) {
+                if (rs.next()) {
                     idexists = true;
                 }
                 prep.close();
                 rs.close();
-                if( idexists ) {
+                if (idexists) {
                     prep = con.prepareStatement("UPDATE context_customfields SET customid=? WHERE cid=?");
                     prep.setString(1, contextExtension.getCustomid());
                     prep.setInt(2, ctx.getId());
@@ -1802,36 +1699,17 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
     }
 
     @Override
-    public CustomField[] deleteCustomFields(final Context ctx) throws StorageException {
+    public void deleteCustomFields(final Context ctx) throws StorageException {
         log.debug("deleteCustomFields from context {}", ctx);
         Connection con = null;
         PreparedStatement prep = null;
-        ResultSet rs = null;
+        final ResultSet rs = null;
         try {
             con = cache.getWriteConnectionForConfigDB();
-
-            prep = con.prepareStatement("SELECT customid, createTimestamp, modifyTimestamp FROM context_customfields WHERE cid=?");
-            prep.setInt(1, ctx.getId().intValue());
-            rs = prep.executeQuery();
-            if (!rs.next()) {
-                return new CustomField[0];
-            }
-
-            List<CustomField> dropped = new LinkedList<CustomField>();
-            do {
-                dropped.add(new CustomField(rs.getString(1), rs.getLong(2), rs.getLong(3)));
-            } while (rs.next());
-            Databases.closeSQLStuff(rs, prep);
-            rs = null;
-            prep = null;
-
             prep = con.prepareStatement("DELETE FROM context_customfields WHERE cid=?");
-            prep.setInt(1, ctx.getId().intValue());
+            prep.setInt(1, ctx.getId());
             prep.executeUpdate();
-            Databases.closeSQLStuff(prep);
-            prep = null;
-
-            return dropped.toArray(new CustomField[dropped.size()]);
+            prep.close();
         } catch (final PoolException e) {
             log.error("", e);
             throw new StorageException(e.getMessage());
@@ -1880,7 +1758,8 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             prep = con.prepareStatement("SELECT * FROM context_customfields WHERE cid=?");
             prep.setInt(1, ctx.getId());
             rs = prep.executeQuery();
-            if( rs.next() ) {
+
+            if (rs.next()) {
                 prep.close();
                 rs.close();
                 prep = con.prepareStatement("UPDATE context_customfields SET modifyTimestamp=? WHERE cid=?");
@@ -1908,7 +1787,7 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             prep.executeUpdate();
             prep.close();
         } finally {
-            DBUtils.closeSQLStuff(prep);
+            closeSQLStuff(prep);
         }
     }
 
@@ -1921,12 +1800,13 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             prep.executeUpdate();
             prep.close();
         } finally {
-            DBUtils.closeSQLStuff(prep);
+            closeSQLStuff(prep);
         }
     }
 
     /*
      * (non-Javadoc)
+     *
      * @see com.openexchange.admin.reseller.storage.interfaces.OXResellerStorageInterface#updateModuleAccessRestrictions()
      */
     @Override
@@ -1941,14 +1821,13 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             cache.initAccessCombinations();
             final HashSet<String> usedCombinations = new HashSet<String>();
             // find out, which restrictions are already used/referenced
-            for(final String query : new String[]{
-                "SELECT r.name FROM subadmin_restrictions AS sr LEFT JOIN restrictions AS r ON ( r.rid=sr.rid ) WHERE r.name LIKE ? OR r.name LIKE ? GROUP BY r.name",
-                "SELECT r.name FROM context_restrictions  AS cr LEFT JOIN restrictions AS r ON ( r.rid=cr.rid ) WHERE r.name LIKE ? OR r.name LIKE ? GROUP BY r.name"}) {
+            // GROUP BY CLAUSE: ensure ONLY_FULL_GROUP_BY compatibility
+            for (final String query : new String[] { "SELECT r.name FROM subadmin_restrictions AS sr LEFT JOIN restrictions AS r ON ( r.rid=sr.rid ) WHERE r.name LIKE ? OR r.name LIKE ? GROUP BY r.name", "SELECT r.name FROM context_restrictions  AS cr LEFT JOIN restrictions AS r ON ( r.rid=cr.rid ) WHERE r.name LIKE ? OR r.name LIKE ? GROUP BY r.name" }) {
                 prep = con.prepareStatement(query);
                 prep.setString(1, Restriction.MAX_OVERALL_USER_PER_SUBADMIN_BY_MODULEACCESS_PREFIX + "%");
                 prep.setString(2, Restriction.MAX_USER_PER_CONTEXT_BY_MODULEACCESS_PREFIX + "%");
                 rs = prep.executeQuery();
-                while( rs.next() ) {
+                while (rs.next()) {
                     usedCombinations.add(rs.getString(1));
                 }
                 prep.close();
@@ -1958,20 +1837,20 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             // if referenced restrictions are going to be removed, throw exception
             final StringBuffer sb = new StringBuffer();
             final HashMap<String, UserModuleAccess> newCombinations = cache.getAccessCombinationNames();
-            for(final String fullname : usedCombinations) {
+            for (final String fullname : usedCombinations) {
                 String cname = null;
-                if( fullname.startsWith(Restriction.MAX_USER_PER_CONTEXT_BY_MODULEACCESS_PREFIX) ) {
+                if (fullname.startsWith(Restriction.MAX_USER_PER_CONTEXT_BY_MODULEACCESS_PREFIX)) {
                     cname = fullname.substring(Restriction.MAX_USER_PER_CONTEXT_BY_MODULEACCESS_PREFIX.length());
-                } else if( fullname.startsWith(Restriction.MAX_OVERALL_USER_PER_SUBADMIN_BY_MODULEACCESS_PREFIX)) {
+                } else if (fullname.startsWith(Restriction.MAX_OVERALL_USER_PER_SUBADMIN_BY_MODULEACCESS_PREFIX)) {
                     cname = fullname.substring(Restriction.MAX_OVERALL_USER_PER_SUBADMIN_BY_MODULEACCESS_PREFIX.length());
                 }
-                if( cname != null  && ! newCombinations.containsKey(cname) ) {
+                if (cname != null && !newCombinations.containsKey(cname)) {
                     sb.append(fullname);
                     sb.append(",");
                 }
             }
-            if( sb.length() > 0 ) {
-                sb.deleteCharAt(sb.length()-1);
+            if (sb.length() > 0) {
+                sb.deleteCharAt(sb.length() - 1);
                 throw new OXResellerException(Code.MODULE_ACCESS_RESTRICTIONS_IN_USE, sb.toString());
             }
 
@@ -1980,24 +1859,24 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
 
             con.setAutoCommit(false);
             rollback = true;
-            for(final String cname : newCombinations.keySet()) {
-                final String percontext  = Restriction.MAX_USER_PER_CONTEXT_BY_MODULEACCESS_PREFIX+cname;
-                final String persubadmin = Restriction.MAX_OVERALL_USER_PER_SUBADMIN_BY_MODULEACCESS_PREFIX+cname;
-                if(!curCombinations.containsKey(percontext)) {
+            for (final String cname : newCombinations.keySet()) {
+                final String percontext = Restriction.MAX_USER_PER_CONTEXT_BY_MODULEACCESS_PREFIX + cname;
+                final String persubadmin = Restriction.MAX_OVERALL_USER_PER_SUBADMIN_BY_MODULEACCESS_PREFIX + cname;
+                if (!curCombinations.containsKey(percontext)) {
                     addRestriction(con, percontext);
                 }
-                if(!curCombinations.containsKey(persubadmin)) {
+                if (!curCombinations.containsKey(persubadmin)) {
                     addRestriction(con, persubadmin);
                 }
             }
-            for(final String fullname : curCombinations.keySet()) {
+            for (final String fullname : curCombinations.keySet()) {
                 String cname = null;
-                if( fullname.startsWith(Restriction.MAX_USER_PER_CONTEXT_BY_MODULEACCESS_PREFIX) ) {
+                if (fullname.startsWith(Restriction.MAX_USER_PER_CONTEXT_BY_MODULEACCESS_PREFIX)) {
                     cname = fullname.substring(Restriction.MAX_USER_PER_CONTEXT_BY_MODULEACCESS_PREFIX.length());
-                } else if( fullname.startsWith(Restriction.MAX_OVERALL_USER_PER_SUBADMIN_BY_MODULEACCESS_PREFIX)) {
+                } else if (fullname.startsWith(Restriction.MAX_OVERALL_USER_PER_SUBADMIN_BY_MODULEACCESS_PREFIX)) {
                     cname = fullname.substring(Restriction.MAX_OVERALL_USER_PER_SUBADMIN_BY_MODULEACCESS_PREFIX.length());
                 }
-                if( cname != null  && ! newCombinations.containsKey(cname) ) {
+                if (cname != null && !newCombinations.containsKey(cname)) {
                     removeRestriction(con, fullname);
                 }
             }
@@ -2043,12 +1922,12 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
 
         final HashSet<String> missingRestrictions = new HashSet<String>();
         final Map<String, Restriction> curCombinations = listRestrictions("*");
-        for(final String res : Restriction.ALL_RESTRICTIONS) {
-            if(! curCombinations.containsKey(res)) {
+        for (final String res : Restriction.ALL_RESTRICTIONS) {
+            if (!curCombinations.containsKey(res)) {
                 missingRestrictions.add(res);
             }
         }
-        if( missingRestrictions.size() > 0 ) {
+        if (missingRestrictions.size() > 0) {
             boolean rollback = false;
             try {
                 con = cache.getWriteConnectionForConfigDB();
