@@ -49,19 +49,20 @@
 
 package com.openexchange.admin.reseller.storage.mysqlStorage;
 
-import static com.openexchange.tools.sql.DBUtils.closeSQLStuff;
-import static com.openexchange.tools.sql.DBUtils.getIN;
 import java.sql.Connection;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.Iterator;
+import java.util.LinkedList;
 import java.util.List;
 import com.openexchange.admin.reseller.rmi.dataobjects.ResellerAdmin;
 import com.openexchange.admin.rmi.exceptions.PoolException;
 import com.openexchange.admin.rmi.exceptions.StorageException;
 import com.openexchange.admin.tools.AdminCache;
+import com.openexchange.database.Databases;
 import com.openexchange.tools.pipesnfilters.Filter;
 import com.openexchange.tools.pipesnfilters.PipesAndFiltersException;
 
@@ -72,7 +73,6 @@ public class ResellerContextFilter implements Filter<Integer, Integer> {
     private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(ResellerContextFilter.class);
 
     private final AdminCache cache;
-
     private final ResellerAdmin admin;
 
     public ResellerContextFilter(AdminCache cache, ResellerAdmin admin) {
@@ -95,52 +95,101 @@ public class ResellerContextFilter implements Filter<Integer, Integer> {
         return cids.toArray(new Integer[cids.size()]);
     }
 
-    private static final String GET_SIDS_SQL = "SELECT sid FROM subadmin WHERE pid = ?";
-
     private List<Integer> filterContexts(Collection<Integer> cids) throws StorageException {
-        final Connection con;
+        Connection con = null;
         try {
             con = cache.getReadConnectionForConfigDB();
+
+            String sqlStmt = buildSqlInStatement(con);
+
+            List<Integer> retval = new ArrayList<>(cids.size());
+            for (Collection<Integer> partition : partition(cids, Databases.IN_LIMIT)) {
+                PreparedStatement stmt = null;
+                ResultSet rs = null;
+                try {
+                    stmt = con.prepareStatement(Databases.getIN(sqlStmt, partition.size()));
+                    int pos = 1;
+                    for (Integer cid : partition) {
+                        stmt.setInt(pos++, cid.intValue());
+                    }
+                    rs = stmt.executeQuery();
+                    while (rs.next()) {
+                        retval.add(Integer.valueOf(rs.getInt(1)));
+                    }
+                } finally {
+                    Databases.closeSQLStuff(rs, stmt);
+                }
+            }
+            return retval;
         } catch (PoolException e) {
             throw new StorageException(e);
+        } catch (SQLException e) {
+            throw new StorageException(e.getMessage(), e);
+        } finally {
+            if (null != con) {
+                try {
+                    cache.pushReadConnectionForConfigDB(con);
+                } catch (PoolException e) {
+                    LOG.error("Error pushing connection to pool!", e);
+                }
+            }
         }
-        List<Integer> retval = new ArrayList<Integer>();
+    }
+
+    private String buildSqlInStatement(Connection con) throws StorageException {
         PreparedStatement stmt = null;
         ResultSet rs = null;
         try {
             // determine all subadmin sids having me as a parent
-            stmt = con.prepareStatement(GET_SIDS_SQL);
-            stmt.setInt(1, admin.getId());
+            stmt = con.prepareStatement("SELECT sid FROM subadmin WHERE pid = ?");
+            stmt.setInt(1, admin.getId().intValue());
             rs = stmt.executeQuery();
-            String GET_CIDS_SQL = "SELECT cid FROM context2subadmin WHERE sid IN (";
-            GET_CIDS_SQL += admin.getId() + ",";
-            while( rs.next() ) {
-                GET_CIDS_SQL += rs.getInt(1) + ",";
-            }
-            GET_CIDS_SQL = GET_CIDS_SQL.substring(0, GET_CIDS_SQL.length()-1);
-            GET_CIDS_SQL += ") AND cid IN (";
-            stmt.close();
-            rs.close();
 
-            stmt = con.prepareStatement(getIN(GET_CIDS_SQL, cids.size()));
-            int pos = 1;
-            for (Integer cid : cids) {
-                stmt.setInt(pos++, cid.intValue());
-            }
-            rs = stmt.executeQuery();
+            StringBuilder stmtBuilder = new StringBuilder("SELECT cid FROM context2subadmin WHERE sid IN (").append(admin.getId());
             while (rs.next()) {
-                retval.add(rs.getInt(1));
+                stmtBuilder.append(", ").append(rs.getInt(1));
             }
+            stmtBuilder.append(") AND cid IN (");
+            return stmtBuilder.toString();
         } catch (SQLException e) {
             throw new StorageException(e.getMessage(), e);
         } finally {
-            closeSQLStuff(rs, stmt);
-            try {
-                cache.pushReadConnectionForConfigDB(con);
-            } catch (PoolException e) {
-                LOG.error("Error pushing connection to pool!", e);
-            }
+            Databases.closeSQLStuff(rs, stmt);
         }
-        return retval;
     }
+
+    /**
+     * Generates consecutive subsets of a set, each of the same size (the final list may be smaller).
+     *
+     * @param original The set to return consecutive subsets of
+     * @param partitionSize The desired size for each subset
+     * @return A list of consecutive subsets
+     * @throws IllegalArgumentException if {@code partitionSize} is not positive
+     */
+    private static <T> List<Collection<T>> partition(Collection<T> original, int partitionSize) {
+        int total = original.size();
+        if (partitionSize >= total) {
+            return java.util.Collections.singletonList(original);
+        }
+
+        // Create a list of collections to return.
+        List<Collection<T>> result = new LinkedList<Collection<T>>();
+
+        // Create an iterator for the original collection.
+        Iterator<T> it = original.iterator();
+
+        // Create each new collection.
+        Collection<T> s = new ArrayList<T>(partitionSize);
+        s.add(it.next());
+        for (int i = 1; i < total; i++) {
+            if ((i % partitionSize) == 0) {
+                result.add(s);
+                s = new ArrayList<T>(partitionSize);
+            }
+            s.add(it.next());
+        }
+        result.add(s);
+        return result;
+    }
+
 }
